@@ -131,8 +131,8 @@ class AWS_KINESISVIDEOMEDIA_API KinesisVideoMediaClient : public Aws::Client::AW
     return SubmitAsync(&KinesisVideoMediaClient::GetMedia, request, handler, context);
   }
 
-  void OverrideEndpoint(const Aws::String& endpoint);
-  std::shared_ptr<KinesisVideoMediaEndpointProviderBase>& accessEndpointProvider();
+  virtual void OverrideEndpoint(const Aws::String& endpoint);
+  virtual std::shared_ptr<KinesisVideoMediaEndpointProviderBase>& accessEndpointProvider();
 
  private:
   friend class Aws::Client::ClientWithAsyncTemplateMethods<KinesisVideoMediaClient>;
