@@ -54,6 +54,24 @@ class UpdateMaxRecordSizeRequest : public KinesisRequest {
   }
   ///@}
 
+  ///@{
+  /**
+   * <p>Not Implemented. Reserved for future use.</p>
+   */
+  inline const Aws::String& GetStreamId() const { return m_streamId; }
+  inline bool StreamIdHasBeenSet() const { return m_streamIdHasBeenSet; }
+  template <typename StreamIdT = Aws::String>
+  void SetStreamId(StreamIdT&& value) {
+    m_streamIdHasBeenSet = true;
+    m_streamId = std::forward<StreamIdT>(value);
+  }
+  template <typename StreamIdT = Aws::String>
+  UpdateMaxRecordSizeRequest& WithStreamId(StreamIdT&& value) {
+    SetStreamId(std::forward<StreamIdT>(value));
+    return *this;
+  }
+  ///@}
+
   ///@{
   /**
    * <p>The maximum record size of a single record in KiB that you can write to, and
@@ -75,8 +93,11 @@ class UpdateMaxRecordSizeRequest : public KinesisRequest {
  private:
   Aws::String m_streamARN;
 
+  Aws::String m_streamId;
+
   int m_maxRecordSizeInKiB{0};
   bool m_streamARNHasBeenSet = false;
+  bool m_streamIdHasBeenSet = false;
   bool m_maxRecordSizeInKiBHasBeenSet = false;
 };
 
