@@ -859,8 +859,8 @@ class AWS_KINESISANALYTICS_API KinesisAnalyticsClient : public Aws::Client::AWSJ
     return SubmitAsync(&KinesisAnalyticsClient::UpdateApplication, request, handler, context);
   }
 
-  void OverrideEndpoint(const Aws::String& endpoint);
-  std::shared_ptr<KinesisAnalyticsEndpointProviderBase>& accessEndpointProvider();
+  virtual void OverrideEndpoint(const Aws::String& endpoint);
+  virtual std::shared_ptr<KinesisAnalyticsEndpointProviderBase>& accessEndpointProvider();
 
  private:
   friend class Aws::Client::ClientWithAsyncTemplateMethods<KinesisAnalyticsClient>;
